#include <iostream>
#include <cstdlib>
#include "barcode.h"

using std::atoi;
using std::cout;

int main(int argc, const char *const *argv)
{
	if(argc < 2 || !strcmp(argv[1], "--help"))
	{
		cout << "Barcode generator v"VERSION" - copyright (C) 1992,2002 Bisqwit (http://bisqwit.iki.fi/)\n"
		        "New versions and support at http://bisqwit.iki.fi/source/barcodetest.html\n"
		        "Usage:\n"
		        "    barcodehelper <stringtoencode> [encodingindex]\n"
		        "\n"
		        "Encoding indexes are defined in /usr/include/barcode.h,\n"
		        "and should be as follows:\n"
		        "\n"
		        "   0=any, 1=ean, 2=upc, 3=isbn, 4=code39,\n"
		        "   5=code128, 6=code128c, 7=code128b, 8=i25,\n"
		        "   9=raw code128, 10=codabar, 11=msi,\n"
		        "   12=plessey, 13=code93.\n"
		        " (At least when this program was written.)\n"
		        "\n"
		        "Output is text, and contains following lines:\n"
		        "  A <input>\n"
		        "  P <the barcode>\n"
		        "  T <text info>\n"
		        "  E <encoding name>\n"
		        "  X <width>\n"
		        "  M <margin>\n"
		        " The barcode is a coded string that should be interpreted as follows:\n"
		        "    digit = width of bar/space (space is first)\n"
		        "    alphabet = width of bar (a=1,b=2,...) and also tells\n"
		        "               that there's no character below/above\n"
		        "    - = characters will be below\n"
		        "    + = characters will be above\n"
		        " Text info is a coded string that contains groups of x:y:c\n"
		        "    where x is x-coordinate, y is y-coordinate and c is the\n"
		        "    character to be printed. Possibly prefixed with +/- as\n"
		        "    previously explained.\n"
		    ;
		return 0;
	}
	Barcode_Item *bc = Barcode_Create(const_cast<char *> (argv[1]));
	
	Barcode_Encode(bc,
		argc>2 ? atoi(argv[2]) : BARCODE_ANY
	);
	
	cout << "A " << bc->ascii << "\n"
	        "P " << bc->partial << "\n"
	        "T " << bc->textinfo << "\n"
	        "E " << bc->encoding << "\n"
	        "X " << bc->width << "\n"
	        "M " << bc->margin << "\n"
	        "Y " << bc->height << "\n"
	        ;
	
	Barcode_Delete(bc);
	return 0;
}
